@@ -9,6 +9,7 @@
 mundo = None
 bg = None
 
+import console
 import sys
 import utils
 from mundo import Mundo
@@ -20,8 +21,9 @@ import sonidos
 import colores
 import atajos
 import escenas
-import ejemplos
 import interfaz
+import aplicacion
+import ejemplos
 
 __doc__ = """
 Módulo pilas
@@ -66,7 +68,7 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qtgl',
     
     global mundo
 
-    motor = __crear_motor(usar_motor)
+    motor = _crear_motor(usar_motor)
     mundo = Mundo(motor, ancho, alto, titulo, rendimiento, economico, gravedad, pantalla_completa)
     escenas.Normal(colores.grisclaro)
 
@@ -83,41 +85,26 @@ def terminar():
     mundo.terminar()
 
 def ver(objeto, imprimir=True, retornar=False):
-    """Imprime en pantalla el codigo fuente asociado a un objeto o elemento de pilas."""
-    import inspect
-
-    try:
-        codigo = inspect.getsource(objeto.__class__)
-    except TypeError:
-        codigo = inspect.getsource(objeto)
-
-    if imprimir:
-        print codigo
-
-    if retornar:
-        return codigo
+    """Imprime en pantalla el codigo fuente asociado a un objeto."""
+    return utils.ver_codigo(objeto, imprimir, retornar)
 
 def version():
     """Retorna el número de version de pilas."""
     import pilasversion
-
     return pilasversion.VERSION
 
-def __crear_motor(usar_motor):
+def _crear_motor(usar_motor):
     """Genera instancia del motor multimedia en base a un nombre.
     
     Esta es una función interna y no debe ser ejecutada
     excepto por el mismo motor pilas."""
 
-    if usar_motor == 'qt':
+    if usar_motor in ['qt', 'qtgl', 'qtsugar']:
         from motores import motor_qt
-        motor = motor_qt.Qt()
-    elif usar_motor == 'qtgl':
-        from motores import motor_qt
-        motor = motor_qt.QtGL()
+        motor = motor_qt.Motor(usar_motor)
     else:
         print "El motor multimedia seleccionado (%s) no esta disponible" %(usar_motor)
-        print "Las opciones de motores que puedes probar son 'qt' y 'qtgl'."
+        print "Las opciones de motores que puedes probar son 'qt', 'qtgl' y 'qtsugar'."
         sys.exit(1)
 
     return motor
@@ -162,11 +149,25 @@ def abrir_cargador():
 
     .. image:: images/cargador.png
     """
-    try:
-        import cargador
 
-        cargador.ejecutar()
+    try:
+        import ejemplos
+        ejemplos.ejecutar()
     except ImportError:
         print "Lo siento, no tienes instalada la extesion de ejemplos."
         print "Instale el paquete 'pilas-examples' para continuar."
+
     return []
+
+def abrir_interprete():
+    """Abre un intérprete interactivo de python con una ventana.
+    
+    Esta función se ejecuta cuando un usuario escribe::
+
+        pilas -i
+
+    en una consola del sistema.
+    """
+
+    import aplicacion
+    aplicacion.main()
