@@ -18,7 +18,13 @@ class Volley(Fondo):
     "Muestra una escena que tiene un fondo de pantalla de paisaje."
 
     def __init__(self):
-        Fondo.__init__(self, "fondos/volley.png")
+        Fondo.__init__(self, "fondos/volley.jpg")
+
+class Nubes(Fondo):
+    "Muestra un fondo celeste con nubes."
+
+    def __init__(self):
+        Fondo.__init__(self, "fondos/nubes.png")
 
 class Pasto(Fondo):
     "Muestra una escena que tiene un fondo de pantalla de paisaje."
@@ -30,29 +36,30 @@ class Selva(Fondo):
     "Muestra una escena que tiene un fondo de pantalla de paisaje."
 
     def __init__(self):
-        Fondo.__init__(self, "fondos/selva.png")
+        Fondo.__init__(self, "fondos/selva.jpg")
 
 
 class Tarde(Fondo):
     "Representa una escena de fondo casi naranja."
 
     def __init__(self):
-        Fondo.__init__(self, "fondos/tarde.png")
+        Fondo.__init__(self, "fondos/tarde.jpg")
 
 
 class Espacio(Fondo):
     "Es un espacio con estrellas."
 
     def __init__(self):
-        Fondo.__init__(self, "fondos/espacio.png")
+        Fondo.__init__(self, "fondos/espacio.jpg")
 
 class Noche(Fondo):
     "Muestra una escena que tiene un fondo de pantalla de paisaje."
 
     def __init__(self):
-        Fondo.__init__(self, "fondos/noche.png")
+        Fondo.__init__(self, "fondos/noche.jpg")
 
 class Color(Fondo):
+    "Pinta todo el fondo de un color uniforme."
     
     def __init__(self, color):
         Fondo.__init__(self, "invisible.png")
